@@ -1,8 +1,8 @@
 package Test::LWP::UserAgent;
 {
-  $Test::LWP::UserAgent::VERSION = '0.003';
+  $Test::LWP::UserAgent::VERSION = '0.004';
 }
-# git description: v0.002-2-g0594f34
+# git description: v0.003-4-ga1fce5f
 
 
 use strict;
@@ -37,7 +37,8 @@ sub map_response
     my ($self, $request_description, $response) = @_;
 
     warn "map_response: response is not an HTTP::Response, it's a " . blessed($response)
-        if not blessed($response) and $response->isa('HTTP::Response');
+        if not (ref $response eq 'CODE' or
+            blessed($response) and $response->isa('HTTP::Response'));
 
     if (blessed($self))
     {
@@ -122,6 +123,12 @@ sub send_request
 
     $last_http_response_received = $self->{__last_http_response_received} =
         ($matched_response || HTTP::Response->new(404));
+
+    $last_http_response_received = $self->{__last_http_response_received} =
+            $last_http_response_received->($request)
+        if ref $last_http_response_received eq 'CODE';
+
+    return $last_http_response_received;
 }
 
 sub __is_regexp($)
@@ -163,6 +170,18 @@ Then, in your tests:
         qr{foo/success}, HTTP::Response->new(200, 'OK', ['Content-Type' => 'text/plain'], ''));
     Test::LWP::UserAgent->map_response(
         qr{foo/fail}, HTTP::Response->new(500, 'ERROR', ['Content-Type' => 'text/plain'], ''));
+    Test::LWP::UserAgent->map_response(
+        qr{foo/conditional},
+        sub {
+            my $request = shift;
+            my $success = $request->uri =~ /success/;
+            return HTTP::Response->new(
+                ($success ? ( 200, 'OK') : (500, 'ERROR'),
+                ['Content-Type' => 'text/plain'], '')
+            )
+        },
+    );
+
 
     # <something which calls the code being tested...>
 
@@ -188,7 +207,9 @@ global.
 =item map_response($request_description, $http_response)
 
 With this method, you set up what L<HTTP::Response> should be returned for each
-request received. The request can be described in multiple ways:
+request received.
+
+The request can be described in multiple ways:
 
 =over 4
 
@@ -228,6 +249,19 @@ parameters, headers etc) against the provided object.
 
 =back
 
+The response can be represented either as a literal L<HTTP::Request> object, or
+as a coderef that is run at the time of matching, with the request passed as
+the single argument:
+
+    HTTP::Response->new(...);
+
+or
+
+    sub {
+        my $request = shift;
+        HTTP::Response->new(...);
+    }
+
 =item unmap_all(instance_only?)
 
 When called as a class method, removes all mappings set up globally (across all
@@ -304,12 +338,14 @@ module, and from where I borrowed some aspects of the API.
 =head1 SEE ALSO
 
 L<Test::Mock::LWP::Dispatch>
+
 L<Test::Mock::LWP::UserAgent>
+
 L<LWP::UserAgent>
 
 =head1 COPYRIGHT
 
-This software is copyright (c) 2012 by Karen Etheridge.
+This software is copyright (c) 2012 by Karen Etheridge, <ether@cpan.org>.
 
 =head1 LICENSE
 
